#![warn(clippy::pedantic)]

use std::fs::File;

use color_eyre::eyre::Result;
use tracing::level_filters::LevelFilter;
use tracing_subscriber::{
    fmt::{self, time::ChronoLocal},
    layer::SubscriberExt,
    util::SubscriberInitExt,
    EnvFilter, Layer,
};

fn main() -> Result<()> {
    color_eyre::install()?;
    crate::init_tracing()?;

    tracing::info!("starting...");
    tracing::debug!("starting debug");

    Ok(())
}

fn init_tracing() -> Result<()> {
    let env_filter = EnvFilter::builder()
        .with_default_directive(LevelFilter::INFO.into())
        .from_env_lossy();

    let log_file = File::create("latest.log")?;

    tracing_subscriber::registry()
        .with(
            fmt::layer()
                .with_timer(ChronoLocal::new("[%H:%M:%S%.3f]".to_string()))
                .with_filter(env_filter),
        )
        .with(
            fmt::layer()
                .with_ansi(false)
                .with_timer(ChronoLocal::new("[%FT%H:%M:%S%.3f]".to_string()))
                .with_writer(log_file)
                .with_filter(LevelFilter::DEBUG),
        )
        .init();

    Ok(())
}
